@@ -2,17 +2,14 @@ import time
 
 from PyQt5 import Qt, QtCore, QtWidgets
 
-import  analysis.statistics as statistics
-import  settings
-import  analysis.optimizer as optimizer
-import  objects.portfolio as portfolio
+import scrilla.analysis.statistics as statistics
+from scrilla import settings
+import scrilla.analysis.optimizer as optimizer
+import scrilla.objects.portfolio as portfolio
 
-import  util.outputter as outputter
-import  util.formatter as formatter
-import  util.helper as helper
-import  util.plotter as plotter
+from scrilla.util import outputter, formatter, helper, plotter
 
-from  gui.widgets import CompositeWidget, GraphWidget, \
+from scrilla.gui.widgets import CompositeWidget, GraphWidget, \
                             TableWidget, PortfolioWidget
 
 logger = outputter.Logger('gui.functions', settings.LOG_LEVEL)
@@ -155,8 +152,8 @@ class OptimizerWidget(PortfolioWidget):
             this_portfolio = portfolio.Portfolio(tickers=user_symbols)
             allocation = optimizer.optimize_portfolio_variance(portfolio=this_portfolio)
             
-            logger.debug(helper.format_allocation_profile(allocation, this_portfolio))
-            self.result.setText(helper.format_allocation_profile(allocation, this_portfolio))
+            logger.debug(formatter.format_allocation_profile(allocation, this_portfolio))
+            self.result.setText(formatter.format_allocation_profile(allocation, this_portfolio))
 
             self.result_table.setRowCount(no_symbols)
             self.result_table.setVerticalHeader(QtWidgets.QHeaderView(QtCore.Qt.Vertical))
