@@ -19,8 +19,6 @@ from objects.portfolio import Portfolio
 from objects.cashflow import Cashflow
 
 if settings.APP_ENV != "container":
-    from PyQt5 import QtWidgets
-    import gui.menu as menu
     import util.plotter as plotter
 
 logger = outputter.Logger('main', settings.LOG_LEVEL)
@@ -41,7 +39,7 @@ non_container_functions = [formatter.FUNC_ARG_DICT['plot_dividends'], formatter.
 
 def validate_function_usage(selection, args, wrapper_function, required_length=1, exact=False):
     if selection in non_container_functions and settings.APP_ENV == 'container':
-        logger.comment('GUI functionality disabled when application is containerized.')
+        logger.comment('Graphics functionality disabled when application is containerized.')
 
     else:
         try:
@@ -93,20 +91,6 @@ def do_program():
         elif opt == formatter.FUNC_ARG_DICT["examples"]:
             outputter.examples()
         
-        ### FUNCTION: Graphical User Interface
-        elif opt == formatter.FUNC_ARG_DICT["gui"] and settings.APP_ENV != "container":
-            app = QtWidgets.QApplication([])
-
-            widget = menu.MenuWidget()
-            widget.resize(settings.GUI_WIDTH, settings.GUI_HEIGHT)
-            widget.show()
-
-            sys.exit(app.exec_())
-
-        # NOTE: Docker doesn't support windowing libraries
-        elif opt == formatter.FUNC_ARG_DICT["gui"] and settings.APP_ENV == "container":
-            logger.comment("GUI functionality disabled when application is containerized.")
-
         ### FUNCTION: Print Stock Watchlist
         elif opt == formatter.FUNC_ARG_DICT['list_watchlist']:
             tickers = files.get_watchlist()
@@ -348,7 +332,7 @@ def do_program():
                             outputter.efficient_frontier(portfolio=portfolio, frontier=frontier,
                                                     investment=xtra_dict['investment'])
                         else:
-                            print(json.dumps(files.format_frontier(portfolio=portfolio, frontier=frontier, investment=xtra_dict['investment'])))
+                            print(json.dumps(formatter.format_frontier(portfolio=portfolio, frontier=frontier, investment=xtra_dict['investment'])))
 
                     if xtra_dict['save_file'] is not None:
                         files.save_frontier(portfolio=portfolio, frontier=frontier,
@@ -368,7 +352,7 @@ def do_program():
                             outputter.optimal_result(portfolio=portfolio, allocation=allocation, 
                                                 investment=xtra_dict['investment'])
                         else:
-                            print(json.dumps(files.format_allocation(allocation=allocation, portfolio=portfolio, investment=xtra_dict['investment'])))
+                            print(json.dumps(formatter.format_allocation(allocation=allocation, portfolio=portfolio, investment=xtra_dict['investment'])))
 
                     if xtra_dict['save_file'] is not None:
                         files.save_allocation(allocation=allocation, portfolio=portfolio, 
@@ -401,7 +385,7 @@ def do_program():
                         if xtra_dict['json'] is None:
                             outputter.optimal_result(portfolio=portfolio, allocation=allocation, investment=xtra_dict['investment'])
                         else:
-                            print(json.dumps(files.format_allocation(allocation=allocation,portfolio=portfolio, investment=xtra_dict['investment'])))
+                            print(json.dumps(formatter.format_allocation(allocation=allocation,portfolio=portfolio, investment=xtra_dict['investment'])))
                     
                     if xtra_dict['save_file'] is not None:
                         files.save_allocation(allocation=allocation, portfolio=portfolio, file_name=xtra_dict['save_file'],
@@ -419,7 +403,7 @@ def do_program():
                         outputter.optimal_result(portfolio=portfolio, allocation=allocation, investment=xtra_dict['investment'])
 
                     if print_json_to_screen(xtra_dict):
-                        print(json.dumps(files.format_allocation(allocation=allocation, portfolio=portfolio, investment=xtra_dict['investment'])))
+                        print(json.dumps(formatter.format_allocation(allocation=allocation, portfolio=portfolio, investment=xtra_dict['investment'])))
                     
                     if xtra_dict['save_file'] is not None:
                         files.save_allocation(allocation=allocation, portfolio=portfolio, file_name=xtra_dict['save_file'],
