@@ -1,7 +1,8 @@
-import datetime, os, math, json
-import holidays
+import datetime, math, holidays
 
-import util.formatter as formatter
+import dateutil.easter as easter
+
+import scrilla.util.formatter as formatter
 
 ################################################
 ##### FORMATTING FUNCTIONS
@@ -47,11 +48,17 @@ def get_today():
 
 def get_last_trading_date():
     today = datetime.datetime.now()
+    if is_date_holiday(today) or is_date_weekend(today):
+        today = get_previous_business_date(today)
     trading_close_today = today.replace(hour=20)
     if today > trading_close_today:
         return today.date()
-    else:
-        return get_previous_business_date(today.date())
+    return get_previous_business_date(today.date())
+
+def this_date_or_last_trading_date(date):
+    if is_date_holiday(date) or is_date_weekend(date):
+        date = get_previous_business_date(date)
+    return date
 
 def validate_date_string(parsed_date_string):
     length_check = (len(parsed_date_string) == 3 )
@@ -62,9 +69,9 @@ def validate_date_string(parsed_date_string):
 
 def validate_order_of_dates(start_date, end_date):
     delta = (end_date - start_date).days
-    if delta > 0 or delta == 0:
-        return start_date, end_date
-    return end_date, start_date
+    if delta < 0:
+        return end_date, start_date
+    return start_date, end_date
 
 # YYYY-MM-DD
 def parse_date_string(date_string) -> datetime.date:
@@ -116,18 +123,34 @@ def is_date_string_today(date) -> bool:
 def is_date_weekend(date) -> bool:
     return date.weekday() in [5, 6]
 
+
+def is_future_date(date):
+    return (date - get_today()).days > 0
+
+def truncate_future_from_date(date):
+    if is_future_date(date):
+        return get_today()
+    return date
+
 # YYYY-MM-DD
 def is_date_string_weekend(date_string) -> bool:
     return is_date_weekend(parse_date_string(date_string))
 
 # YYYY-MM-DD
-def is_date_holiday(date_string) -> bool:
-    us_holidays = holidays.UnitedStates()
-    return (date_string in us_holidays)
+def is_date_holiday(date : datetime.date) -> bool:
+    us_holidays = holidays.UnitedStates(years=date.year)
+    # generate list without columbus day since markets are open on columbus day
+    custom_holidays = [ date for date in us_holidays if us_holidays[date] != "Columbus Day" ]
+    # add good friday to list since markets are closed on good friday
+    custom_holidays.append(easter.easter(year=date.year) - datetime.timedelta(days=2))
 
-def is_date_string_holiday(date) -> bool:
-    return is_date_holiday(parse_date_string(date))
+    return (date in custom_holidays)
 
+def is_date_string_holiday(date_string) -> bool:
+    return is_date_holiday(parse_date_string(date_string))
+
+def is_trading_date(date):
+    return not is_date_weekend(date) and not is_date_holiday(date)
 
 # YYYY-MM-DD
 def get_holidays_between(start_date_string, end_date_string) -> int:
@@ -200,7 +223,7 @@ def business_dates_between(start_date, end_date):
 def business_days_between(start_date, end_date):
     new_start, new_end = validate_order_of_dates(start_date, end_date)
     dates = dates_between(new_start, new_end)
-    return len([1 for day in dates if day.weekday() < 5])
+    return len([1 for date in dates if not (is_date_weekend(date) or is_date_holiday(date))])
 
 def weekends_between(start_date, end_date):
     start_date, end_date = verify_date_types(dates=[start_date, end_date])
@@ -310,102 +333,90 @@ def get_time_to_next_period(starting_date, period):
 def get_start_date(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['start_date'] in xtra_args:
         unparsed_start = xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['start_date'])]
-        start_date = parse_date_string(unparsed_start)
-    else:
-        start_date = None
-    return start_date
+        return parse_date_string(unparsed_start)
+    return None
 
 def get_end_date(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['end_date'] in xtra_args:
         unparsed_end = xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['end_date'])]
-        end_date = parse_date_string(unparsed_end)
-    else:
-        end_date = None
-    return end_date
+        return parse_date_string(unparsed_end)
+    return None
 
 def get_save_file(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['save'] in xtra_args:
-        save_file = xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['save'])]
-    else:
-        save_file = None
-    return save_file
+        return xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['save'])]
+    return None
 
 def get_target(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['target'] in xtra_args:
         try:
-            target = float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['target'])])
-        except ValueError:
-            target = None
-    else:
-        target = None
-    return target
+            return float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['target'])])
+        except ValueError as ve:
+            raise ve
+    return None
 
 def get_expiry(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['expiry'] in xtra_args:
         try:
-            expiry = float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['expiry'])])
-        except ValueError:
-            expiry = None
-    else:
-        expiry = None
-    return expiry
+            return float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['expiry'])])
+        except ValueError as ve:
+            raise ve
+    return None
 
 def get_probability(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['probability'] in xtra_args:
         try:
-            probability = float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['probability'])])
-        except ValueError:
-            probability = None
-    else:
-        probability = None
-    return probability
+            return float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['probability'])])
+        except ValueError as ve:
+            raise ve
+    return None
 
 def get_discount(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['discount'] in xtra_args:
         try:
-            discount = float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['discount'])])
-        except ValueError:
-            discount = None
-    else:
-        discount = None
-    return discount
+            return float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['discount'])])
+        except ValueError as ve:
+            raise ve
+    return None
 
 def get_model(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['model'] in xtra_args:
-        model = str(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['model'])]).lower()
-    else:
-        model = None
-    return model
+        return str(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['model'])]).lower()
+    return None
 
 def get_sharpe(xtra_args):
     if formatter.FUNC_XTRA_SINGLE_ARGS_DICT['optimize_sharpe'] in xtra_args:
-        sharpe = formatter.FUNC_XTRA_SINGLE_ARGS_DICT['optimize_sharpe']
-    else:
-        sharpe = None
-    return sharpe
+        return formatter.FUNC_XTRA_SINGLE_ARGS_DICT['optimize_sharpe']
+    return None
+
+def get_suppress_output(xtra_args):
+    if formatter.FUNC_XTRA_SINGLE_ARGS_DICT['suppress_output'] in xtra_args:
+        return formatter.FUNC_XTRA_SINGLE_ARGS_DICT['suppress_output']
+    return None
+
+def get_json(xtra_args):
+    if formatter.FUNC_XTRA_SINGLE_ARGS_DICT['json'] in xtra_args:
+        return formatter.FUNC_XTRA_SINGLE_ARGS_DICT['json']
+    return None
 
 def get_investment(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['investment'] in xtra_args:
         try:
-            investment = float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['investment'])])
-        except ValueError:
-            investment = None
-    else:
-        investment = None
-    return investment
+            return float(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT['investment'])])
+        except ValueError as ve:
+            raise ve
+    return None
 
 def get_steps(xtra_args, xtra_values):
     if formatter.FUNC_XTRA_VALUED_ARGS_DICT['steps'] in xtra_args:
         try:
-            steps = int(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT)])
-        except ValueError:
-            steps = None
-    else:
-        steps = None
-    return steps
+            return int(xtra_values[xtra_args.index(formatter.FUNC_XTRA_VALUED_ARGS_DICT)])
+        except ValueError as ve:
+            raise ve
+    return None
 
-def format_xtra_args_list(xtra_args, xtra_values):
-    arg_list = {
+def format_xtra_args_dict(xtra_args, xtra_values):
+    return {
         'start_date': get_start_date(xtra_args, xtra_values),
         'end_date': get_end_date(xtra_args, xtra_values),
         'save_file': get_save_file(xtra_args, xtra_values),
@@ -415,13 +426,12 @@ def format_xtra_args_list(xtra_args, xtra_values):
         'investment': get_investment(xtra_args, xtra_values),
         'steps': get_steps(xtra_args, xtra_values),
         'optimize_sharpe': get_sharpe(xtra_args),
+        'suppress': get_suppress_output(xtra_args),
+        'json': get_json(xtra_args),
         'expiry': get_expiry(xtra_args, xtra_values),
         'probability': get_probability(xtra_args, xtra_values)
     }
-    return arg_list
 
-# TODO: single arg functions screw up argument parsing.
-#       example: scrilla -opt-
 def separate_and_parse_args(args):
     extra_args, extra_values= [], []
     reduced_args = args
@@ -447,7 +457,7 @@ def separate_and_parse_args(args):
     return (extra_args, extra_values, reduced_args)
     
 ### APPLICATION PARSING
-#should be in formatter.py
+#should be in ...? somewhere that is not here. outputter, probably. 
 def format_allocation_profile(allocation, portfolio) -> str:
     port_return, port_volatility = portfolio.return_function(allocation), portfolio.volatility_function(allocation)
     formatted_result = "("+str(100*port_return)[:5]+"%, " + str(100*port_volatility)[:5]+"%)"
